from setuptools import setup

setup(name='GBI_distributions',
      version='0.2',
      description='Gaussian distributions',
      packages=['GBI_distributions'],
      author = 'Parinaz Farajiparvar',
      zip_safe=False)
